@@ -1,27 +1,19 @@
 import haiku as hk
 import jax
 import jax.numpy as jnp
-from e3nn_jax import (
-    Irreps,
-    IrrepsArray,
-    FunctionalTensorProduct,
-    index_add,
-    Linear,
-    FullyConnectedTensorProduct,
-    MultiLayerPerceptron,
-)
+import e3nn_jax as e3nn
 
 
 class TensorProductMultiLayerPerceptron(hk.Module):
-    irreps_in1: Irreps
-    irreps_in2: Irreps
-    irreps_out: Irreps
+    irreps_in1: e3nn.Irreps
+    irreps_in2: e3nn.Irreps
+    irreps_out: e3nn.Irreps
 
-    def __init__(self, tp: FunctionalTensorProduct, list_neurons, act):
+    def __init__(self, tp: e3nn.FunctionalTensorProduct, list_neurons, act):
         super().__init__()
 
         self.tp = tp
-        self.mlp = MultiLayerPerceptron(list_neurons, act)
+        self.mlp = e3nn.MultiLayerPerceptron(list_neurons, act)
 
         self.irreps_in1 = tp.irreps_in1.simplify()
         self.irreps_in2 = tp.irreps_in2.simplify()
@@ -29,7 +21,7 @@ class TensorProductMultiLayerPerceptron(hk.Module):
 
         assert all(i.has_weight for i in self.tp.instructions)
 
-    def __call__(self, emb, x1: IrrepsArray, x2: IrrepsArray) -> IrrepsArray:
+    def __call__(self, emb, x1: e3nn.IrrepsArray, x2: e3nn.IrrepsArray) -> e3nn.IrrepsArray:
         w = self.mlp(emb)
 
         w = [
@@ -65,7 +57,7 @@ def _instructions_uvu(irreps_in1, irreps_in2, out_ir_list):
                     k = len(irreps_out)
                     irreps_out.append((mul, ir_out))
                     instructions.append((i1, i2, k, "uvu", True))
-    irreps_out = Irreps(irreps_out)
+    irreps_out = e3nn.Irreps(irreps_out)
 
     irreps_out, p, _ = irreps_out.sort()
     instructions = [(i_1, i_2, p[i_out], mode, has_weight) for i_1, i_2, i_out, mode, has_weight in instructions]
@@ -73,9 +65,11 @@ def _instructions_uvu(irreps_in1, irreps_in2, out_ir_list):
     return irreps_out, instructions
 
 
-def _tp_mlp_uvu(emb, input1: IrrepsArray, input2: IrrepsArray, out_ir_list, *, list_neurons, act) -> IrrepsArray:
+def _tp_mlp_uvu(
+    emb, input1: e3nn.IrrepsArray, input2: e3nn.IrrepsArray, out_ir_list, *, list_neurons, act
+) -> e3nn.IrrepsArray:
     irreps_out, instructions = _instructions_uvu(input1.irreps, input2.irreps, out_ir_list)
-    tp = FunctionalTensorProduct(input1.irreps, input2.irreps, irreps_out, instructions)
+    tp = e3nn.FunctionalTensorProduct(input1.irreps, input2.irreps, irreps_out, instructions)
     return TensorProductMultiLayerPerceptron(tp, list_neurons, act)(emb, input1, input2)
 
 
@@ -87,25 +81,32 @@ class Transformer(hk.Module):
     def __init__(self, irreps_node_output, list_neurons, act, num_heads=1):
         super().__init__()
 
-        self.irreps_node_output = Irreps(irreps_node_output)
+        self.irreps_node_output = e3nn.Irreps(irreps_node_output)
         self.list_neurons = list_neurons
         self.act = act
         self.num_heads = num_heads
 
     def __call__(
-        self, edge_src, edge_dst, edge_scalar_attr, edge_weight_cutoff, edge_attr: IrrepsArray, node_feat: IrrepsArray
-    ) -> IrrepsArray:
-        r"""
+        self,
+        edge_src,
+        edge_dst,
+        edge_scalar_attr,
+        edge_weight_cutoff,
+        edge_attr: e3nn.IrrepsArray,
+        node_feat: e3nn.IrrepsArray,
+    ) -> e3nn.IrrepsArray:
+        r"""Equivariant Transformer.
+
         Args:
             edge_src (array of int32): source index of the edges
             edge_dst (array of int32): destination index of the edges
             edge_scalar_attr (array of float): scalar attributes of the edges (typically given by ``soft_one_hot_linspace``)
             edge_weight_cutoff (array of float): cutoff weight for the edges (typically given by ``sus``)
-            edge_attr (IrrepsArray): attributes of the edges (typically given by ``spherical_harmonics``)
-            node_f (IrrepsArray): features of the nodes
+            edge_attr (e3nn.IrrepsArray): attributes of the edges (typically given by ``spherical_harmonics``)
+            node_f (e3nn.IrrepsArray): features of the nodes
 
         Returns:
-            IrrepsArray: output features of the nodes
+            e3nn.IrrepsArray: output features of the nodes
         """
         edge_src_feat = jax.tree_util.tree_map(lambda x: x[edge_src], node_feat)
         edge_dst_feat = jax.tree_util.tree_map(lambda x: x[edge_dst], node_feat)
@@ -118,18 +119,16 @@ class Transformer(hk.Module):
             edge_scalar_attr, edge_src_feat, edge_attr
         )  # IrrepData[edge, irreps]
 
-        edge_logit = jax.vmap(FullyConnectedTensorProduct(f"{self.num_heads}x0e"))(
-            edge_dst_feat, edge_k
-        ).array  # array[edge, head]
+        edge_logit = e3nn.Linear(f"{self.num_heads}x0e")(e3nn.tensor_product(edge_dst_feat, edge_k)).array  # array[edge, head]
         node_logit_max = _index_max(edge_dst, edge_logit, node_feat.shape[0])  # array[node, head]
         exp = edge_weight_cutoff[:, None] * jnp.exp(edge_logit - node_logit_max[edge_dst])  # array[edge, head]
-        z = index_add(edge_dst, exp, out_dim=node_feat.shape[0])  # array[node, head]
+        z = e3nn.index_add(edge_dst, exp, out_dim=node_feat.shape[0])  # array[node, head]
         z = jnp.where(z == 0.0, 1.0, z)
         alpha = exp / z[edge_dst]  # array[edge, head]
 
-        edge_v = edge_v.factor_mul_to_last_axis(self.num_heads)  # IrrepsArray[edge, head, irreps_out]
-        edge_v = edge_v * jnp.sqrt(jax.nn.relu(alpha))[:, :, None]  # IrrepsArray[edge, head, irreps_out]
-        edge_v = edge_v.repeat_mul_by_last_axis()  # IrrepsArray[edge, irreps_out]
+        edge_v = edge_v.factor_mul_to_last_axis(self.num_heads)  # e3nn.IrrepsArray[edge, head, irreps_out]
+        edge_v = edge_v * jnp.sqrt(jax.nn.relu(alpha))[:, :, None]  # e3nn.IrrepsArray[edge, head, irreps_out]
+        edge_v = edge_v.repeat_mul_by_last_axis()  # e3nn.IrrepsArray[edge, irreps_out]
 
-        node_out = index_add(edge_dst, edge_v, out_dim=node_feat.shape[0])  # IrrepsArray[node, irreps_out]
-        return jax.vmap(Linear(self.irreps_node_output))(node_out)  # IrrepsArray[edge, head, irreps_out]
+        node_out = e3nn.index_add(edge_dst, edge_v, out_dim=node_feat.shape[0])  # e3nn.IrrepsArray[node, irreps_out]
+        return e3nn.Linear(self.irreps_node_output)(node_out)  # e3nn.IrrepsArray[edge, head, irreps_out]
